// Modified by Keerthi Kanth Reddy Sathi
// Fig. 9.8: Time.h
// Declaration of class Time.
// Member functions defined in Time.cpp.

// prevent multiple inclusions of header file
#ifndef TIME_H
#define TIME_H

// Time abstract data type definition
class Time 
{
public:
   Time( int = 0, int = 0, int = 0 ); // default constructor

   // set functions
   void setTime( int, int, int ); // set hour, minute, second
   void setHour( int ); // set hour (after validation)
   void setMinute( int ); // set minute (after validation)
   void setSecond( int ); // set second (after validation)

   // get functions
   int getHour(); // return hour
   int getMinute(); // return minute
   int getSecond(); // return second

   void printUniversal(); // output time in universal-time format
   void printStandard(); // output time in standard-time format
   void tick();                   //tick member function to increment 
								  //time stored in Time object by one second
private:
   int hour; // 0 - 23 (24-hour clock format)
   int minute; // 0 - 59
   int second; // 0 - 59
}; // end class Time

#endif

/**************************************************************************
 * (C) Copyright 1992-2005 by Deitel & Associates, Inc. and               *
 * Pearson Education, Inc. All Rights Reserved.                           *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 **************************************************************************/

// Fig. 9.9: Time.cpp
// Member-function definitions for class Time.
#include <iostream>
using std::cout;

#include <iomanip>
using std::setfill;
using std::setw;

#include "Time.h" // include definition of class Time from Time.h

// Time constructor initializes each data member to zero;
// ensures that Time objects start in a consistent state
Time::Time( int hr, int min, int sec ) 
{ 
   setTime( hr, min, sec ); // validate and set time
} // end Time constructor

// set new Time value using universal time; ensure that
// the data remains consistent by setting invalid values to zero
void Time::setTime( int h, int m, int s )
{
   setHour( h ); // set private field hour
   setMinute( m ); // set private field minute
   setSecond( s ); // set private field second
} // end function setTime

// set hour value
void Time::setHour( int h )
{
   hour = ( h >= 0 && h < 24 ) ? h : 0; // validate hour
} // end function setHour

// set minute value
void Time::setMinute( int m )
{
   minute = ( m >= 0 && m < 60 ) ? m : 0; // validate minute
} // end function setMinute

// set second value
void Time::setSecond( int s )
{
   second = ( s >= 0 && s < 60 ) ? s : 0; // validate second
} // end function setSecond

// return hour value
int Time::getHour()
{
   return hour;
} // end function getHour

// return minute value
int Time::getMinute()
{
   return minute;
} // end function getMinute

// return second value
int Time::getSecond()
{
   return second;
} // end function getSecond

// print Time in universal-time format (HH:MM:SS)
void Time::printUniversal()
{
   cout << setfill( '0' ) << setw( 2 ) << getHour() << ":"
      << setw( 2 ) << getMinute() << ":" << setw( 2 ) << getSecond();
} // end function printUniversal

// print Time in standard-time format (HH:MM:SS AM or PM)
void Time::printStandard()
{
   cout << ( ( getHour() == 0 || getHour() == 12 ) ? 12 : getHour() % 12 )
      << ":" << setfill( '0' ) << setw( 2 ) << getMinute()
      << ":" << setw( 2 ) << getSecond() << ( hour < 12 ? " AM" : " PM" );
} // end function printStandard

// Function to increment time by one second
void Time::tick()
{
	second = second + 1;
	if (second >=60)
	{
		minute++;
		second = 0;
		if(minute>=60)
		{
			hour++;
			minute=0;
			{
				if(hour>=24)
				{
//					hour++;	not needed - MGR
					hour=0;
				}
                  }
            }
       }
}

/**************************************************************************
 * (C) Copyright 1992-2005 by Deitel & Associates, Inc. and               *
 * Pearson Education, Inc. All Rights Reserved.                           *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 **************************************************************************/

// Modidfied by Keerthi Kanth Reddy Sathi
// CS 202 Hw #3 Problem 2
// Fig. 9.10: fig09_10.cpp 
// Demonstrating a default constructor for class Time.
#include <iostream>
using std::cout;
using std::endl;

#include "Time.h" // include definition of class Time from Time.h

int main()
{
   Time t1(11,20,50); 
   Time t2( 5,59,50); 
   Time t3( 23,59,50);
 
   cout << "Incrementing to the next minute\n";
   for(int i=0;i<10;i++)
   {
   t1.tick();
   t1.printUniversal();
   cout<<"    ";
   t1.printStandard(); // 12:00:00 AM
    cout << "\n";
   }
   cout << "\nIncrementing to the next hour\n";
   for(int i=0;i<10;i++)
   {
   t2.tick();
   t2.printUniversal();
   cout<<"    ";
   t2.printStandard(); // 12:00:00 AM
    cout << "\n";
   }
cout << "\nIncrementing to the next day\n";
   for(int i=0;i<10;i++)
   {
   t3.tick();
   t3.printUniversal();
   cout<<"    ";
   t3.printStandard(); // 12:00:00 AM
    cout << "\n";
   }
   return 0;
} // end main

/**************************************************************************
 * (C) Copyright 1992-2005 by Deitel & Associates, Inc. and               *
 * Pearson Education, Inc. All Rights Reserved.                           *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 **************************************************************************/

/* OUTPUT :
Incrementing to the next minute
11:20:51    11:20:51 AM
11:20:52    11:20:52 AM
11:20:53    11:20:53 AM
11:20:54    11:20:54 AM
11:20:55    11:20:55 AM
11:20:56    11:20:56 AM
11:20:57    11:20:57 AM
11:20:58    11:20:58 AM
11:20:59    11:20:59 AM
11:21:00    11:21:00 AM

Incrementing to the next hour
05:59:51    5:59:51 AM
05:59:52    5:59:52 AM
05:59:53    5:59:53 AM
05:59:54    5:59:54 AM
05:59:55    5:59:55 AM
05:59:56    5:59:56 AM
05:59:57    5:59:57 AM
05:59:58    5:59:58 AM
05:59:59    5:59:59 AM
06:00:00    6:00:00 AM

Incrementing to the next day
23:59:51    11:59:51 PM
23:59:52    11:59:52 PM
23:59:53    11:59:53 PM
23:59:54    11:59:54 PM
23:59:55    11:59:55 PM
23:59:56    11:59:56 PM
23:59:57    11:59:57 PM
23:59:58    11:59:58 PM
23:59:59    11:59:59 PM
00:00:00    12:00:00 AM
Press any key to continue
*/

